#############################################################
## ADJUSTABLE PARAMETERS                                   ##
#############################################################
structure          INPUT_NAMD/adp.psf
firsttimestep       0

#############################################################
## SIMULATION PARAMETERS                                   ##
#############################################################

#Input
paraTypeCharmm	    on
parameters          par_all22_prot.inp
temperature         $temperature

# Force-Field Parameters
exclude             scaled1-4
1-4scaling          1.0
cutoff              800
switching           on
switchdist          700
pairlistdist        900
stepspercycle       10

#############################################################
## Prepare configuration                                   ##
#############################################################
# Restrain dihedrals
tclForces           on
tclForcesScript {
   set aid1  13
   set aid2  15
   set aid3  17
   set aid4  1
   set aid5  3   

   set k   $kcst

   addatom $aid1
   addatom $aid2
   addatom $aid3
   addatom $aid4
   addatom $aid5

   set PI 3.1415926535897931
   
   proc calcforces  {} {
     global aid1 aid2 aid3 aid4 aid5 k PI phi0 psi0 equilstep
     loadcoords p
     
     set phi [getdihedral $p($aid1) $p($aid2) $p($aid3) $p($aid4)]
     set psi [getdihedral $p($aid2) $p($aid3) $p($aid4) $p($aid5)]

     set ntwoPI  [expr -2*$PI]
     set nPI     [expr -1*$PI]
     
     #new method to calc differences
     set d0 [expr fmod($phi-$phi0, 360)]
     set d1 [expr fmod($psi-$psi0, 360)]
     set df0  [expr $d0*$PI/180]
     set df1  [expr $d1*$PI/180]

     if {$df0 > $PI} {
       set df0 [expr $df0 + $ntwoPI]
     } elseif { $df0 < $nPI } {
       set df0 [expr $df0 - $ntwoPI]  
     } else {
     }
     if {$df1 > $PI} {
       set df1 [expr $df1 + $ntwoPI]
     } elseif { $df1 < $nPI } {
       set df1 [expr $df1 - $ntwoPI]  
     } else {
     }

     addenergy [expr $k*($df0*$df0+$df1*$df1)/2.0]
     set force0 [expr -$k*$df0]
     set force1 [expr -$k*$df1]

     foreach {g1 g2 g3 g4} [dihedralgrad $p($aid1) $p($aid2) $p($aid3) $p($aid4)]  {}
     foreach {h1 h2 h3 h4} [dihedralgrad $p($aid2) $p($aid3) $p($aid4) $p($aid5)]  {}
     
     addforce $aid1 [vecscale $g1 $force0]
     addforce $aid2 [vecadd [vecscale $g2 $force0] [vecscale $h1 $force1]]
     addforce $aid3 [vecadd [vecscale $g3 $force0] [vecscale $h2 $force1]]
     addforce $aid4 [vecadd [vecscale $g4 $force0] [vecscale $h3 $force1]]
     addforce $aid5 [vecscale $h4 $force1]
   }
}  

# Integrator Parameters
timestep            1.0  ;
#rigidBonds         all  ;# needed for 2fs steps
nonbondedFreq       1
fullElectFrequency  2  

# Constant Temperature Control
langevin            on
langevinDamping     10.0
langevinTemp        $temperature
langevinHydrogen    no 

# Output
outputName           $outputname
binaryoutput         no
outputEnergies       $equilstep        

run $equilstep